﻿using MediatR;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using ProxmoxConnector.Server.Application.Queries.System;
using System;
using System.Threading.Tasks;

namespace ProxmoxConnector.Server.Controllers
{
    [Authorize]
    [ApiController]
    [Route("health")]
    public class HealthController : ControllerBase
    {
        private readonly ILogger<HealthController> _logger;
        private readonly IMediator _mediator;

        public HealthController(ILogger<HealthController> logger, IMediator mediator)
        {
            _logger = logger;
            _mediator = mediator;
        }

        [AllowAnonymous]
        [HttpGet("ping")]
        public IActionResult Ping()
        {
            _logger.LogInformation("Ping");
            return Ok($"Ping success. System datetime: {DateTime.Now}");
        }

        [AllowAnonymous]
        [HttpGet("version")]
        public async Task<IActionResult> GetSystemVersion([FromRoute] GetSystemVersion.Query query)
        {
            var result = await _mediator.Send(query);
            return Ok(result);
        }
    }
}
